@@ -1,12 +1,10 @@
 from typing import Optional, Union
 from datetime import datetime
 import json
-import os
-import copy
 
 from cqlpy.types import *
 from cqlpy.operators import *
-from valueset_provider import ValueSetProvider
+from cqlpy.valueset_provider import ValueSetProvider
 
 
 class Context:
@@ -56,6 +54,9 @@ class Context:
             with open(bundle_file_name, encoding="utf-8") as f:
                 bundle = json.loads(f.read())
 
+        if bundle is None:
+            raise ValueError("bundle or bundle_file_name must be specified")
+
         self.model = FhirR4DataModel(bundle, self)
 
         self.cql_valueset_provider = CqlValueSetProvider(
